@@ -1,4 +1,4 @@
-// A Bison parser, made by GNU Bison 3.7.6.
+// A Bison parser, made by GNU Bison 3.8.2.
 
 // Skeleton interface for Bison LALR(1) parsers in C++
 
@@ -132,12 +132,18 @@ using namespace std;
 # define YY_USE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
+# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
+# else
+#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
     _Pragma ("GCC diagnostic push")                                     \
     _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# endif
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
@@ -199,7 +205,7 @@ using namespace std;
 
 #line 14 "netconf_parser.yy"
 namespace isc { namespace netconf {
-#line 203 "netconf_parser.h"
+#line 209 "netconf_parser.h"
 
 
 
@@ -208,27 +214,32 @@ namespace isc { namespace netconf {
   class NetconfParser
   {
   public:
-#ifndef NETCONF_STYPE
+#ifdef NETCONF_STYPE
+# ifdef __GNUC__
+#  pragma GCC message "bison: do not #define NETCONF_STYPE in C++, use %define api.value.type"
+# endif
+    typedef NETCONF_STYPE value_type;
+#else
   /// A buffer to store and retrieve objects.
   ///
   /// Sort of a variant, but does not keep track of the nature
   /// of the stored data, since that knowledge is available
   /// via the current parser state.
-  class semantic_type
+  class value_type
   {
   public:
     /// Type of *this.
-    typedef semantic_type self_type;
+    typedef value_type self_type;
 
     /// Empty construction.
-    semantic_type () YY_NOEXCEPT
-      : yybuffer_ ()
+    value_type () YY_NOEXCEPT
+      : yyraw_ ()
       , yytypeid_ (YY_NULLPTR)
     {}
 
     /// Construct and fill.
     template <typename T>
-    semantic_type (YY_RVREF (T) t)
+    value_type (YY_RVREF (T) t)
       : yytypeid_ (&typeid (T))
     {
       NETCONF__ASSERT (sizeof (T) <= size);
@@ -237,13 +248,13 @@ namespace isc { namespace netconf {
 
 #if 201103L <= YY_CPLUSPLUS
     /// Non copyable.
-    semantic_type (const self_type&) = delete;
+    value_type (const self_type&) = delete;
     /// Non copyable.
     self_type& operator= (const self_type&) = delete;
 #endif
 
     /// Destruction, allowed only if empty.
-    ~semantic_type () YY_NOEXCEPT
+    ~value_type () YY_NOEXCEPT
     {
       NETCONF__ASSERT (!yytypeid_);
     }
@@ -387,7 +398,7 @@ namespace isc { namespace netconf {
   private:
 #if YY_CPLUSPLUS < 201103L
     /// Non copyable.
-    semantic_type (const self_type&);
+    value_type (const self_type&);
     /// Non copyable.
     self_type& operator= (const self_type&);
 #endif
@@ -397,7 +408,7 @@ namespace isc { namespace netconf {
     T*
     yyas_ () YY_NOEXCEPT
     {
-      void *yyp = yybuffer_.yyraw;
+      void *yyp = yyraw_;
       return static_cast<T*> (yyp);
      }
 
@@ -406,7 +417,7 @@ namespace isc { namespace netconf {
     const T*
     yyas_ () const YY_NOEXCEPT
     {
-      const void *yyp = yybuffer_.yyraw;
+      const void *yyp = yyraw_;
       return static_cast<const T*> (yyp);
      }
 
@@ -438,18 +449,19 @@ namespace isc { namespace netconf {
     union
     {
       /// Strongest alignment constraints.
-      long double yyalign_me;
+      long double yyalign_me_;
       /// A buffer large enough to store any of the semantic values.
-      char yyraw[size];
-    } yybuffer_;
+      char yyraw_[size];
+    };
 
     /// Whether the content is built: if defined, the name of the stored type.
     const std::type_info *yytypeid_;
   };
 
-#else
-    typedef NETCONF_STYPE semantic_type;
 #endif
+    /// Backward compatibility (Bison 3.8).
+    typedef value_type semantic_type;
+
     /// Symbol locations.
     typedef location location_type;
 
@@ -532,7 +544,7 @@ namespace isc { namespace netconf {
     };
 
     /// Token kind, as returned by yylex.
-    typedef token::yytokentype token_kind_type;
+    typedef token::token_kind_type token_kind_type;
 
     /// Backward compatibility alias (Bison 3.6).
     typedef token_kind_type token_type;
@@ -616,82 +628,83 @@ namespace isc { namespace netconf {
         S_69_7 = 69,                             // $@7
         S_global_object = 70,                    // global_object
         S_71_8 = 71,                             // $@8
-        S_global_params = 72,                    // global_params
-        S_not_empty_global_params = 73,          // not_empty_global_params
-        S_global_param = 74,                     // global_param
-        S_boot_update = 75,                      // boot_update
-        S_subscribe_changes = 76,                // subscribe_changes
-        S_validate_changes = 77,                 // validate_changes
-        S_user_context = 78,                     // user_context
-        S_79_9 = 79,                             // $@9
-        S_comment = 80,                          // comment
-        S_81_10 = 81,                            // $@10
-        S_hooks_libraries = 82,                  // hooks_libraries
-        S_83_11 = 83,                            // $@11
-        S_hooks_libraries_list = 84,             // hooks_libraries_list
-        S_not_empty_hooks_libraries_list = 85,   // not_empty_hooks_libraries_list
-        S_hooks_library = 86,                    // hooks_library
-        S_87_12 = 87,                            // $@12
-        S_hooks_params = 88,                     // hooks_params
-        S_hooks_param = 89,                      // hooks_param
-        S_library = 90,                          // library
-        S_91_13 = 91,                            // $@13
-        S_parameters = 92,                       // parameters
-        S_93_14 = 93,                            // $@14
-        S_managed_servers = 94,                  // managed_servers
-        S_95_15 = 95,                            // $@15
-        S_servers_entries = 96,                  // servers_entries
-        S_not_empty_servers_entries = 97,        // not_empty_servers_entries
-        S_server_entry = 98,                     // server_entry
-        S_dhcp4_server = 99,                     // dhcp4_server
-        S_100_16 = 100,                          // $@16
-        S_dhcp6_server = 101,                    // dhcp6_server
-        S_102_17 = 102,                          // $@17
-        S_d2_server = 103,                       // d2_server
-        S_104_18 = 104,                          // $@18
-        S_ca_server = 105,                       // ca_server
-        S_106_19 = 106,                          // $@19
-        S_managed_server_params = 107,           // managed_server_params
-        S_managed_server_param = 108,            // managed_server_param
-        S_model = 109,                           // model
-        S_110_20 = 110,                          // $@20
-        S_control_socket = 111,                  // control_socket
-        S_112_21 = 112,                          // $@21
-        S_control_socket_params = 113,           // control_socket_params
-        S_control_socket_param = 114,            // control_socket_param
-        S_socket_type = 115,                     // socket_type
-        S_116_22 = 116,                          // $@22
-        S_socket_type_value = 117,               // socket_type_value
-        S_socket_name = 118,                     // socket_name
-        S_119_23 = 119,                          // $@23
-        S_socket_url = 120,                      // socket_url
-        S_121_24 = 121,                          // $@24
-        S_loggers = 122,                         // loggers
-        S_123_25 = 123,                          // $@25
-        S_loggers_entries = 124,                 // loggers_entries
-        S_logger_entry = 125,                    // logger_entry
-        S_126_26 = 126,                          // $@26
-        S_logger_params = 127,                   // logger_params
-        S_logger_param = 128,                    // logger_param
-        S_name = 129,                            // name
-        S_130_27 = 130,                          // $@27
-        S_debuglevel = 131,                      // debuglevel
-        S_severity = 132,                        // severity
-        S_133_28 = 133,                          // $@28
-        S_output_options_list = 134,             // output_options_list
-        S_135_29 = 135,                          // $@29
-        S_output_options_list_content = 136,     // output_options_list_content
-        S_output_entry = 137,                    // output_entry
-        S_138_30 = 138,                          // $@30
-        S_output_params_list = 139,              // output_params_list
-        S_output_params = 140,                   // output_params
-        S_output = 141,                          // output
-        S_142_31 = 142,                          // $@31
-        S_flush = 143,                           // flush
-        S_maxsize = 144,                         // maxsize
-        S_maxver = 145,                          // maxver
-        S_pattern = 146,                         // pattern
-        S_147_32 = 147                           // $@32
+        S_global_object_comma = 72,              // global_object_comma
+        S_global_params = 73,                    // global_params
+        S_not_empty_global_params = 74,          // not_empty_global_params
+        S_global_param = 75,                     // global_param
+        S_boot_update = 76,                      // boot_update
+        S_subscribe_changes = 77,                // subscribe_changes
+        S_validate_changes = 78,                 // validate_changes
+        S_user_context = 79,                     // user_context
+        S_80_9 = 80,                             // $@9
+        S_comment = 81,                          // comment
+        S_82_10 = 82,                            // $@10
+        S_hooks_libraries = 83,                  // hooks_libraries
+        S_84_11 = 84,                            // $@11
+        S_hooks_libraries_list = 85,             // hooks_libraries_list
+        S_not_empty_hooks_libraries_list = 86,   // not_empty_hooks_libraries_list
+        S_hooks_library = 87,                    // hooks_library
+        S_88_12 = 88,                            // $@12
+        S_hooks_params = 89,                     // hooks_params
+        S_hooks_param = 90,                      // hooks_param
+        S_library = 91,                          // library
+        S_92_13 = 92,                            // $@13
+        S_parameters = 93,                       // parameters
+        S_94_14 = 94,                            // $@14
+        S_managed_servers = 95,                  // managed_servers
+        S_96_15 = 96,                            // $@15
+        S_servers_entries = 97,                  // servers_entries
+        S_not_empty_servers_entries = 98,        // not_empty_servers_entries
+        S_server_entry = 99,                     // server_entry
+        S_dhcp4_server = 100,                    // dhcp4_server
+        S_101_16 = 101,                          // $@16
+        S_dhcp6_server = 102,                    // dhcp6_server
+        S_103_17 = 103,                          // $@17
+        S_d2_server = 104,                       // d2_server
+        S_105_18 = 105,                          // $@18
+        S_ca_server = 106,                       // ca_server
+        S_107_19 = 107,                          // $@19
+        S_managed_server_params = 108,           // managed_server_params
+        S_managed_server_param = 109,            // managed_server_param
+        S_model = 110,                           // model
+        S_111_20 = 111,                          // $@20
+        S_control_socket = 112,                  // control_socket
+        S_113_21 = 113,                          // $@21
+        S_control_socket_params = 114,           // control_socket_params
+        S_control_socket_param = 115,            // control_socket_param
+        S_socket_type = 116,                     // socket_type
+        S_117_22 = 117,                          // $@22
+        S_socket_type_value = 118,               // socket_type_value
+        S_socket_name = 119,                     // socket_name
+        S_120_23 = 120,                          // $@23
+        S_socket_url = 121,                      // socket_url
+        S_122_24 = 122,                          // $@24
+        S_loggers = 123,                         // loggers
+        S_124_25 = 124,                          // $@25
+        S_loggers_entries = 125,                 // loggers_entries
+        S_logger_entry = 126,                    // logger_entry
+        S_127_26 = 127,                          // $@26
+        S_logger_params = 128,                   // logger_params
+        S_logger_param = 129,                    // logger_param
+        S_name = 130,                            // name
+        S_131_27 = 131,                          // $@27
+        S_debuglevel = 132,                      // debuglevel
+        S_severity = 133,                        // severity
+        S_134_28 = 134,                          // $@28
+        S_output_options_list = 135,             // output_options_list
+        S_136_29 = 136,                          // $@29
+        S_output_options_list_content = 137,     // output_options_list_content
+        S_output_entry = 138,                    // output_entry
+        S_139_30 = 139,                          // $@30
+        S_output_params_list = 140,              // output_params_list
+        S_output_params = 141,                   // output_params
+        S_output = 142,                          // output
+        S_143_31 = 143,                          // $@31
+        S_flush = 144,                           // flush
+        S_maxsize = 145,                         // maxsize
+        S_maxver = 146,                          // maxver
+        S_pattern = 147,                         // pattern
+        S_148_32 = 148                           // $@32
       };
     };
 
@@ -714,7 +727,7 @@ namespace isc { namespace netconf {
       typedef Base super_type;
 
       /// Default constructor.
-      basic_symbol ()
+      basic_symbol () YY_NOEXCEPT
         : value ()
         , location ()
       {}
@@ -849,6 +862,8 @@ namespace isc { namespace netconf {
         clear ();
       }
 
+
+
       /// Destroy contents, and record that is empty.
       void clear () YY_NOEXCEPT
       {
@@ -910,7 +925,7 @@ switch (yykind)
       void move (basic_symbol& s);
 
       /// The semantic value.
-      semantic_type value;
+      value_type value;
 
       /// The location.
       location_type location;
@@ -925,22 +940,24 @@ switch (yykind)
     /// Type access provider for token (enum) based symbols.
     struct by_kind
     {
-      /// Default constructor.
-      by_kind ();
-
-#if 201103L <= YY_CPLUSPLUS
-      /// Move constructor.
-      by_kind (by_kind&& that);
-#endif
-
-      /// Copy constructor.
-      by_kind (const by_kind& that);
-
       /// The symbol kind as needed by the constructor.
       typedef token_kind_type kind_type;
 
+      /// Default constructor.
+      by_kind () YY_NOEXCEPT;
+
+#if 201103L <= YY_CPLUSPLUS
+      /// Move constructor.
+      by_kind (by_kind&& that) YY_NOEXCEPT;
+#endif
+
+      /// Copy constructor.
+      by_kind (const by_kind& that) YY_NOEXCEPT;
+
       /// Constructor from (external) token numbers.
-      by_kind (kind_type t);
+      by_kind (kind_type t) YY_NOEXCEPT;
+
+
 
       /// Record that this symbol is empty.
       void clear () YY_NOEXCEPT;
@@ -970,59 +987,69 @@ switch (yykind)
       typedef basic_symbol<by_kind> super_type;
 
       /// Empty symbol.
-      symbol_type () {}
+      symbol_type () YY_NOEXCEPT {}
 
       /// Constructor for valueless symbols, and symbols from each type.
 #if 201103L <= YY_CPLUSPLUS
       symbol_type (int tok, location_type l)
-        : super_type(token_type (tok), std::move (l))
+        : super_type (token_kind_type (tok), std::move (l))
 #else
       symbol_type (int tok, const location_type& l)
-        : super_type(token_type (tok), l)
+        : super_type (token_kind_type (tok), l)
 #endif
       {
+#if !defined _MSC_VER || defined __clang__
         NETCONF__ASSERT (tok == token::TOKEN_END
                    || (token::TOKEN_NETCONF_error <= tok && tok <= token::TOKEN_START_SUB_NETCONF));
+#endif
       }
 #if 201103L <= YY_CPLUSPLUS
       symbol_type (int tok, bool v, location_type l)
-        : super_type(token_type (tok), std::move (v), std::move (l))
+        : super_type (token_kind_type (tok), std::move (v), std::move (l))
 #else
       symbol_type (int tok, const bool& v, const location_type& l)
-        : super_type(token_type (tok), v, l)
+        : super_type (token_kind_type (tok), v, l)
 #endif
       {
+#if !defined _MSC_VER || defined __clang__
         NETCONF__ASSERT (tok == token::TOKEN_BOOLEAN);
+#endif
       }
 #if 201103L <= YY_CPLUSPLUS
       symbol_type (int tok, double v, location_type l)
-        : super_type(token_type (tok), std::move (v), std::move (l))
+        : super_type (token_kind_type (tok), std::move (v), std::move (l))
 #else
       symbol_type (int tok, const double& v, const location_type& l)
-        : super_type(token_type (tok), v, l)
+        : super_type (token_kind_type (tok), v, l)
 #endif
       {
+#if !defined _MSC_VER || defined __clang__
         NETCONF__ASSERT (tok == token::TOKEN_FLOAT);
+#endif
       }
 #if 201103L <= YY_CPLUSPLUS
       symbol_type (int tok, int64_t v, location_type l)
-        : super_type(token_type (tok), std::move (v), std::move (l))
+        : super_type (token_kind_type (tok), std::move (v), std::move (l))
 #else
       symbol_type (int tok, const int64_t& v, const location_type& l)
-        : super_type(token_type (tok), v, l)
+        : super_type (token_kind_type (tok), v, l)
 #endif
       {
+#if !defined _MSC_VER || defined __clang__
         NETCONF__ASSERT (tok == token::TOKEN_INTEGER);
+#endif
       }
 #if 201103L <= YY_CPLUSPLUS
       symbol_type (int tok, std::string v, location_type l)
-        : super_type(token_type (tok), std::move (v), std::move (l))
+        : super_type (token_kind_type (tok), std::move (v), std::move (l))
 #else
       symbol_type (int tok, const std::string& v, const location_type& l)
-        : super_type(token_type (tok), v, l)
+        : super_type (token_kind_type (tok), v, l)
 #endif
       {
+#if !defined _MSC_VER || defined __clang__
         NETCONF__ASSERT (tok == token::TOKEN_STRING);
+#endif
       }
     };
 
@@ -1071,7 +1098,7 @@ switch (yykind)
     /// YYSYMBOL.  No bounds checking.
     static std::string symbol_name (symbol_kind_type yysymbol);
 
-    // Implementation of make_symbol for each symbol type.
+    // Implementation of make_symbol for each token kind.
 #if 201103L <= YY_CPLUSPLUS
       static
       symbol_type
@@ -1853,19 +1880,19 @@ switch (yykind)
 
     /// Whether the given \c yypact_ value indicates a defaulted state.
     /// \param yyvalue   the value to check
-    static bool yy_pact_value_is_default_ (int yyvalue);
+    static bool yy_pact_value_is_default_ (int yyvalue) YY_NOEXCEPT;
 
     /// Whether the given \c yytable_ value indicates a syntax error.
     /// \param yyvalue   the value to check
-    static bool yy_table_value_is_error_ (int yyvalue);
+    static bool yy_table_value_is_error_ (int yyvalue) YY_NOEXCEPT;
 
     static const signed char yypact_ninf_;
     static const signed char yytable_ninf_;
 
     /// Convert a scanner token kind \a t to a symbol kind.
     /// In theory \a t should be a token_kind_type, but character literals
-    /// are valid, yet not members of the token_type enum.
-    static symbol_kind_type yytranslate_ (int t);
+    /// are valid, yet not members of the token_kind_type enum.
+    static symbol_kind_type yytranslate_ (int t) YY_NOEXCEPT;
 
     /// Convert the symbol name \a n to a form suitable for a diagnostic.
     static std::string yytnamerr_ (const char *yystr);
@@ -1885,7 +1912,7 @@ switch (yykind)
     static const unsigned char yydefact_[];
 
     // YYPGOTO[NTERM-NUM].
-    static const short yypgoto_[];
+    static const signed char yypgoto_[];
 
     // YYDEFGOTO[NTERM-NUM].
     static const short yydefgoto_[];
@@ -1897,14 +1924,14 @@ switch (yykind)
 
     static const short yycheck_[];
 
-    // YYSTOS[STATE-NUM] -- The (internal number of the) accessing
-    // symbol of state STATE-NUM.
+    // YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
+    // state STATE-NUM.
     static const unsigned char yystos_[];
 
-    // YYR1[YYN] -- Symbol number of symbol that rule YYN derives.
+    // YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.
     static const unsigned char yyr1_[];
 
-    // YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.
+    // YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.
     static const signed char yyr2_[];
 
 
@@ -2003,7 +2030,7 @@ switch (yykind)
       typedef typename S::size_type size_type;
       typedef typename std::ptrdiff_t index_type;
 
-      stack (size_type n = 200)
+      stack (size_type n = 200) YY_NOEXCEPT
         : seq_ (n)
       {}
 
@@ -2082,7 +2109,7 @@ switch (yykind)
       class slice
       {
       public:
-        slice (const stack& stack, index_type range)
+        slice (const stack& stack, index_type range) YY_NOEXCEPT
           : stack_ (stack)
           , range_ (range)
         {}
@@ -2132,13 +2159,13 @@ switch (yykind)
     void yypush_ (const char* m, state_type s, YY_MOVE_REF (symbol_type) sym);
 
     /// Pop \a n symbols from the stack.
-    void yypop_ (int n = 1);
+    void yypop_ (int n = 1) YY_NOEXCEPT;
 
     /// Constants.
     enum
     {
-      yylast_ = 219,     ///< Last index in yytable_.
-      yynnts_ = 99,  ///< Number of nonterminal symbols.
+      yylast_ = 221,     ///< Last index in yytable_.
+      yynnts_ = 100,  ///< Number of nonterminal symbols.
       yyfinal_ = 8 ///< Termination state number.
     };
 
@@ -2150,7 +2177,7 @@ switch (yykind)
 
   inline
   NetconfParser::symbol_kind_type
-  NetconfParser::yytranslate_ (int t)
+  NetconfParser::yytranslate_ (int t) YY_NOEXCEPT
   {
     // YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to
     // TOKEN-NUM as returned by yylex.
@@ -2196,7 +2223,7 @@ switch (yykind)
     if (t <= 0)
       return symbol_kind::S_YYEOF;
     else if (t <= code_max)
-      return YY_CAST (symbol_kind_type, translate_table[t]);
+      return static_cast <symbol_kind_type> (translate_table[t]);
     else
       return symbol_kind::S_YYUNDEF;
   }
@@ -2240,6 +2267,7 @@ switch (yykind)
 
 
 
+
   template <typename Base>
   NetconfParser::symbol_kind_type
   NetconfParser::basic_symbol<Base>::type_get () const YY_NOEXCEPT
@@ -2247,6 +2275,7 @@ switch (yykind)
     return this->kind ();
   }
 
+
   template <typename Base>
   bool
   NetconfParser::basic_symbol<Base>::empty () const YY_NOEXCEPT
@@ -2292,13 +2321,13 @@ switch (yykind)
 
   // by_kind.
   inline
-  NetconfParser::by_kind::by_kind ()
+  NetconfParser::by_kind::by_kind () YY_NOEXCEPT
     : kind_ (symbol_kind::S_YYEMPTY)
   {}
 
 #if 201103L <= YY_CPLUSPLUS
   inline
-  NetconfParser::by_kind::by_kind (by_kind&& that)
+  NetconfParser::by_kind::by_kind (by_kind&& that) YY_NOEXCEPT
     : kind_ (that.kind_)
   {
     that.clear ();
@@ -2306,15 +2335,17 @@ switch (yykind)
 #endif
 
   inline
-  NetconfParser::by_kind::by_kind (const by_kind& that)
+  NetconfParser::by_kind::by_kind (const by_kind& that) YY_NOEXCEPT
     : kind_ (that.kind_)
   {}
 
   inline
-  NetconfParser::by_kind::by_kind (token_kind_type t)
+  NetconfParser::by_kind::by_kind (token_kind_type t) YY_NOEXCEPT
     : kind_ (yytranslate_ (t))
   {}
 
+
+
   inline
   void
   NetconfParser::by_kind::clear () YY_NOEXCEPT
@@ -2337,6 +2368,7 @@ switch (yykind)
     return kind_;
   }
 
+
   inline
   NetconfParser::symbol_kind_type
   NetconfParser::by_kind::type_get () const YY_NOEXCEPT
@@ -2344,9 +2376,10 @@ switch (yykind)
     return this->kind ();
   }
 
+
 #line 14 "netconf_parser.yy"
 } } // isc::netconf
-#line 2350 "netconf_parser.h"
+#line 2383 "netconf_parser.h"
 
 
 
