@@ -1,17 +1,22 @@
-// Copyright (C) 2018-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 #include <config.h>
+
 #include <netconf/netconf_cfg_mgr.h>
 #include <netconf/netconf_process.h>
 #include <asiolink/interval_timer.h>
 #include <asiolink/io_service.h>
 #include <process/testutils/d_test_stubs.h>
+#include <testutils/gtest_utils.h>
+
 #include <boost/date_time/posix_time/posix_time.hpp>
+
 #include <gtest/gtest.h>
+
 #include <functional>
 
 using namespace boost::posix_time;
@@ -52,7 +57,7 @@ TEST(NetconfProcess, construction) {
 
     // Verify that the constructor succeeds with a valid io_service
     lcl_io_service.reset(new IOService());
-    ASSERT_NO_THROW(NetconfProcess("TestProcess", lcl_io_service));
+    ASSERT_NO_THROW_LOG(NetconfProcess("TestProcess", lcl_io_service));
 
     // Verify tha the configuration is accessible after construction.
     NetconfProcess netconf_process("TestProcess", lcl_io_service);
