@@ -37,12 +37,13 @@ namespace dhcp {
 /// @brief Base class for PostgreSQL Config Backend implementations.
 ///
 /// This class contains common methods for manipulating data in the
-/// Postgres database, used by all servers.
+/// PostgreSQL database, used by all servers.
 ///
 /// All POSIX times specified in the methods belonging to this
 /// class must be local times.
 class PgSqlConfigBackendImpl {
 protected:
+
     /// @brief RAII object used to protect against creating multiple
     /// audit revisions during cascade configuration updates.
     ///
@@ -68,13 +69,14 @@ protected:
     /// transaction with the database.
     class ScopedAuditRevision {
     public:
+
         /// @brief Constructor.
         ///
         /// Creates new audit revision and sets the flag in the
-        /// Postgres CB implementation object which prevents new audit
+        /// PostgreSQL CB implementation object which prevents new audit
         /// revisions to be created while this instance exists.
         ///
-        /// @param impl pointer to the Postgres CB implementation.
+        /// @param impl pointer to the PostgreSQL CB implementation.
         /// @param index index of the query to set session variables
         /// used for creation of the audit revision and the audit
         /// entries.
@@ -98,18 +100,23 @@ protected:
         ~ScopedAuditRevision();
 
     private:
-        /// @brief Pointer to the Postgres CB implementation.
+
+        /// @brief Pointer to the PostgreSQL CB implementation.
         PgSqlConfigBackendImpl* impl_;
     };
 
 public:
+
     /// @brief Constructor.
     ///
     /// @param parameters A data structure relating keywords and values
     /// concerned with the database.
     /// @param db_reconnect_callback The connection recovery callback.
+    /// @param last_insert_id_index statement index of the SQL statement to
+    /// use when fetching the last insert id for a given table.
     explicit PgSqlConfigBackendImpl(const db::DatabaseConnection::ParameterMap& parameters,
-                                    const db::DbCallback db_reconnect_callback);
+                                    const db::DbCallback db_reconnect_callback,
+                                    const size_t last_insert_id_index);
 
     /// @brief Destructor.
     virtual ~PgSqlConfigBackendImpl();
@@ -127,14 +134,13 @@ public:
     /// @return Server tag.
     /// @throw InvalidOperation if the server selector is unassigned or if there
     /// is more than one server tag associated with the selector.
-    std::string
-    getServerTag(const db::ServerSelector& server_selector, const std::string& operation) const {
-        auto tags = server_selector.getTags();
+    std::string getServerTag(const db::ServerSelector& server_selector,
+                             const std::string& operation) const {
+        auto const& tags = server_selector.getTags();
         if (tags.size() != 1) {
             isc_throw(InvalidOperation, "expected exactly one server tag to be specified"
-                                        " while "
-                                            << operation
-                                            << ". Got: " << getServerTagsAsText(server_selector));
+                      " while " << operation << ". Got: "
+                      << getServerTagsAsText(server_selector));
         }
 
         return (tags.begin()->get());
@@ -146,8 +152,8 @@ public:
     /// This method is useful for logging purposes.
     std::string getServerTagsAsText(const db::ServerSelector& server_selector) const {
         std::ostringstream s;
-        auto server_tags = server_selector.getTags();
-        for (auto tag : server_tags) {
+        auto const& server_tags = server_selector.getTags();
+        for (auto const& tag : server_tags) {
             if (s.tellp() != 0) {
                 s << ", ";
             }
@@ -273,8 +279,7 @@ public:
     /// @param column name of the sequence column
     /// @return returns the most recently modified value for the given
     /// sequence
-    uint64_t getLastInsertId(const int index, const std::string& table,
-                             const std::string& column);
+    uint64_t getLastInsertId(const std::string& table, const std::string& column);
 
     /// @brief Sends query to retrieve multiple global parameters.
     ///
@@ -355,6 +360,9 @@ public:
     /// @param create_audit_revision Statement creating audit revision.
     /// @param insert_option_def_server Statement associating option
     /// definition with a server.
+    /// @param client_class_name Optional client class name to which
+    /// the option definition belongs. If this value is not specified,
+    /// it is a global option definition.
     /// @throw NotImplemented if server selector is "unassigned".
     void createUpdateOptionDef(const db::ServerSelector& server_selector,
                                const OptionDefinitionPtr& option_def,
@@ -363,7 +371,8 @@ public:
                                const int& insert_option_def,
                                const int& update_option_def,
                                const int& create_audit_revision,
-                               const int& insert_option_def_server);
+                               const int& insert_option_def_server,
+                               const std::string& client_class_name = "");
 
     /// @brief Sends query to retrieve single global option by code and
     /// option space.
@@ -481,7 +490,56 @@ public:
                     const Option::Universe& universe,
                     OptionContainer& options);
 
-    /// @todo implement OptionDescriptorPtr processOptionRow(const Option::Universe& universe, ...)
+    /// @brief Returns DHCP option instance from a set of columns within a
+    /// result set row.
+    ///
+    /// The following is the expected order of columns specified in the SELECT
+    /// query:
+    /// - option_id,
+    /// - code,
+    /// - value,
+    /// - formatted_value,
+    /// - space,
+    /// - persistent,
+    /// - dhcp4_subnet_id/dhcp6_subnet_id,
+    /// - scope_id,
+    /// - user_context,
+    /// - shared_network_name,
+    /// - pool_id,
+    /// - [pd_pool_id,]
+    /// - modification_ts
+    ///
+    /// @note The universe is reused to switch between DHCPv4 and DHCPv6
+    /// option layouts.
+    /// @param universe V4 or V6.
+    /// @param worker result set row worker containing the row data
+    /// @param first_col column index of the first column (i.e. option_id)
+    /// in the row.
+    OptionDescriptorPtr processOptionRow(const Option::Universe& universe,
+                                         db::PgSqlResultRowWorker& worker,
+                                         const size_t first_col);
+
+    /// @brief Returns DHCP option definition instance from output bindings.
+    ///
+    /// The following is the expected order of columns specified in the SELECT
+    /// query:
+    /// - id,
+    /// - code,
+    /// - name,
+    /// - space,
+    /// - type,
+    /// - modification_ts,
+    /// - is_array,
+    /// - encapsulate,
+    /// - record_types,
+    /// - user_context
+    ///
+    /// @param worker result set row worker containing the row data
+    /// @param first_col column index of the first column (i.e. definition id)
+    /// in the row.
+    /// @return Pointer to the option definition.
+    OptionDefinitionPtr processOptionDefRow(db::PgSqlResultRowWorker& worker,
+                                            const size_t first_col);
 
     /// @brief Associates a configuration element with multiple servers.
     ///
@@ -505,6 +563,19 @@ public:
     /// should be created.
     void addRelayBinding(db::PsqlBindArray& bindings, const NetworkPtr& network);
 
+    /// @brief Iterates over the relay addresses in a JSON list element at a
+    /// given column, adding each to the given Network's relay list.
+    ///
+    /// Has no effect if the column is null or is an empty list.
+    ///
+    /// @param worker result set row worker containing the row data
+    /// @param col column index of JSON element column
+    /// @param network network to update.
+    ///
+    /// @throw BadValue if the Element is not a list or if any of the
+    /// list's elements are not valid IP addresses in string form.
+    void setRelays(db::PgSqlResultRowWorker& r, size_t col, Network& network);
+
     /// @brief Adds 'require_client_classes' parameter to a bind array.
     ///
     /// Creates an Element tree of required class names and adds that to the end
@@ -530,6 +601,20 @@ public:
         bindings.add(required_classes_element);
     }
 
+    /// @brief Iterates over the class names in a JSON list element at a
+    /// given column, invoking a setter function for each one.
+    ///
+    /// Has no effect if the column is null or is an empty list.
+    ///
+    /// @param worker result set row worker containing the row data
+    /// @param col column index of JSON element column
+    /// @param setter function to invoke for each class name in the list
+    ///
+    /// @throw BadValue if the Element is not a list or if any of the
+    /// list's elements are not strings.
+    void setRequiredClasses(db::PgSqlResultRowWorker& worker, size_t col,
+                            std::function<void(const std::string&)> setter);
+
     /// @brief Adds an option value to a bind array.
     ///
     /// @param bindings PsqlBindArray to which the option value should be added.
@@ -560,8 +645,9 @@ public:
     /// @param bindings Reference to the PgSQL input bindings.
     /// @param [out] servers Reference to the container where fetched servers
     /// will be inserted.
-    void
-    getServers(const int index, const db::PsqlBindArray& bindings, db::ServerCollection& servers);
+    void getServers(const int index,
+                    const db::PsqlBindArray& bindings,
+                    db::ServerCollection& servers);
 
     /// @brief Creates or updates a server.
     ///
@@ -621,9 +707,9 @@ public:
     /// @param server_selector Server selector.
     /// @param index Reference to the index holding the returned configuration
     /// elements to be processed.
-    template <typename CollectionIndex>
-    void
-    tossNonMatchingElements(const db::ServerSelector& server_selector, CollectionIndex& index) {
+    template<typename CollectionIndex>
+    void tossNonMatchingElements(const db::ServerSelector& server_selector,
+                                 CollectionIndex& index) {
         // Don't filter the matching server tags if the server selector is
         // set to ANY.
         if (server_selector.amAny()) {
@@ -655,10 +741,11 @@ public:
                 // Server selector contains explicit server tags, so
                 // let's see if the returned elements includes any of
                 // them.
-                auto tags = server_selector.getTags();
+                auto const& tags = server_selector.getTags();
                 bool tag_found = false;
-                for (auto tag : tags) {
-                    if ((*elem)->hasServerTag(tag) || (*elem)->hasAllServerTag()) {
+                for (auto const& tag : tags) {
+                    if ((*elem)->hasServerTag(tag) ||
+                        (*elem)->hasAllServerTag()) {
                         tag_found = true;
                         break;
                     }
@@ -679,7 +766,7 @@ public:
 
     /// @brief Returns backend type in the textual format.
     ///
-    /// @return "pgsql".
+    /// @return "postgresql".
     std::string getType() const;
 
     /// @brief Returns backend host.
@@ -707,7 +794,7 @@ public:
         return (parameters_);
     }
 
-    /// @brief Sets IO service to be used by the Postgres config backend.
+    /// @brief Sets IO service to be used by the PostgreSQL config backend.
     ///
     /// @param IOService object, used for all ASIO operations.
     static void setIOService(const isc::asiolink::IOServicePtr& io_service) {
@@ -779,23 +866,28 @@ public:
     /// @return Number of affected rows.
     uint64_t updateDeleteQuery(size_t index, const db::PsqlBindArray& in_bindings);
 
-    /// @brief Represents connection to the Postgres database.
+    /// @brief Represents connection to the PostgreSQL database.
     db::PgSqlConnection conn_;
 
 protected:
+
     /// @brief Timer name used to register database reconnect timer.
     std::string timer_name_;
 
 private:
-    /// @brief Boolean flag indicating if audit revision has been created
-    /// using @c ScopedAuditRevision object.
-    bool audit_revision_created_;
+
+    /// @brief Reference counter for @ScopedAuditRevision instances.
+    int audit_revision_ref_count_;
 
     /// @brief Connection parameters
     isc::db::DatabaseConnection::ParameterMap parameters_;
 
-    /// The IOService object, used for all ASIO operations.
+    /// @brief The IOService object, used for all ASIO operations.
     static isc::asiolink::IOServicePtr io_service_;
+
+    /// @brief Statement index of the SQL statement to use for fetching
+    /// last inserted id in a given table.
+    size_t last_insert_id_index_;
 };
 
 }  // namespace dhcp
