@@ -1,20 +1,15 @@
-// Copyright (C) 2011-2015 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2022 Internet Systems Consortium, Inc. ("ISC")
 //
-// Permission to use, copy, modify, and/or distribute this software for any
-// purpose with or without fee is hereby granted, provided that the above
-// copyright notice and this permission notice appear in all copies.
-//
-// THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
-// REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
-// AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
-// INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
-// LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
-// OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
-// PERFORMANCE OF THIS SOFTWARE.
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
+#include <config.h>
 
 #include <dhcp/dhcp6.h>
 #include <dhcp/libdhcp++.h>
 #include <dhcp/option.h>
+#include <dhcp/option_space.h>
 #include <dhcp/option_vendor_class.h>
 #include <dhcp/option_vendor.h>
 #include <dhcp/pkt6.h>
@@ -24,6 +19,7 @@
 #include <dhcp/duid.h>
 #include <dhcp/iface_mgr.h>
 
+#include <iterator>
 #include <iostream>
 #include <sstream>
 
@@ -41,6 +37,19 @@ Pkt6::RelayInfo::RelayInfo()
     peeraddr_(DEFAULT_ADDRESS6), relay_msg_len_(0) {
 }
 
+std::string Pkt6::RelayInfo::toText() const {
+    stringstream tmp;
+    tmp << "msg-type=" << static_cast<int>(msg_type_) << "(" << getName(msg_type_)
+        << "), hop-count=" << static_cast<int>(hop_count_)  << "," << endl
+        << "link-address=" << linkaddr_.toText()
+        << ", peer-address=" << peeraddr_.toText() << ", "
+        << options_.size() << " option(s)" << endl;
+    for (auto option = options_.cbegin(); option != options_.cend(); ++option) {
+        tmp << option->second->toText() << endl;
+    }
+    return (tmp.str());
+}
+
 Pkt6::Pkt6(const uint8_t* buf, uint32_t buf_len, DHCPv6Proto proto /* = UDP */)
    :Pkt(buf, buf_len, DEFAULT_ADDRESS6, DEFAULT_ADDRESS6, 0, 0),
     proto_(proto), msg_type_(0) {
@@ -63,17 +72,9 @@ size_t Pkt6::len() {
     }
 }
 
-OptionPtr Pkt6::getAnyRelayOption(uint16_t opt_type, RelaySearchOrder order) {
-
-    if (relay_info_.empty()) {
-        // There's no relay info, this is a direct message
-        return (OptionPtr());
-    }
-
-    int start = 0; // First relay to check
-    int end = 0;   // Last relay to check
-    int direction = 0; // How we going to iterate: forward or backward?
-
+void
+Pkt6::prepareGetAnyRelayOption(const RelaySearchOrder& order,
+                               int& start, int& end, int& direction) const {
     switch (order) {
     case RELAY_SEARCH_FROM_CLIENT:
         // Search backwards
@@ -99,6 +100,22 @@ OptionPtr Pkt6::getAnyRelayOption(uint16_t opt_type, RelaySearchOrder order) {
         end = 0;
         direction = 1;
     }
+}
+
+
+OptionPtr
+Pkt6::getNonCopiedAnyRelayOption(const uint16_t option_code,
+                                 const RelaySearchOrder& order) const {
+    if (relay_info_.empty()) {
+        // There's no relay info, this is a direct message
+        return (OptionPtr());
+    }
+
+    int start = 0; // First relay to check
+    int end = 0;   // Last relay to check
+    int direction = 0; // How we going to iterate: forward or backward?
+
+    prepareGetAnyRelayOption(order, start, end, direction);
 
     // This is a tricky loop. It must go from start to end, but it must work in
     // both directions (start > end; or start < end). We can't use regular
@@ -107,7 +124,7 @@ OptionPtr Pkt6::getAnyRelayOption(uint16_t opt_type, RelaySearchOrder order) {
     // list (end + direction). It is similar to STL concept of end pointing
     // to a place after the last element
     for (int i = start; i != end + direction; i += direction) {
-        OptionPtr opt = getRelayOption(opt_type, i);
+        OptionPtr opt = getNonCopiedRelayOption(option_code, i);
         if (opt) {
             return (opt);
         }
@@ -118,20 +135,96 @@ OptionPtr Pkt6::getAnyRelayOption(uint16_t opt_type, RelaySearchOrder order) {
     return (OptionPtr());
 }
 
-OptionPtr Pkt6::getRelayOption(uint16_t opt_type, uint8_t relay_level) {
+OptionPtr
+Pkt6::getAnyRelayOption(const uint16_t option_code,
+                        const RelaySearchOrder& order) {
+
+    if (relay_info_.empty()) {
+        // There's no relay info, this is a direct message
+        return (OptionPtr());
+    }
+
+    int start = 0; // First relay to check
+    int end = 0;   // Last relay to check
+    int direction = 0; // How we going to iterate: forward or backward?
+
+    prepareGetAnyRelayOption(order, start, end, direction);
+
+    // This is a tricky loop. It must go from start to end, but it must work in
+    // both directions (start > end; or start < end). We can't use regular
+    // exit condition, because we don't know whether to use i <= end or i >= end.
+    // That's why we check if in the next iteration we would go past the
+    // list (end + direction). It is similar to STL concept of end pointing
+    // to a place after the last element
+    for (int i = start; i != end + direction; i += direction) {
+        OptionPtr opt = getRelayOption(option_code, i);
+        if (opt) {
+            return (opt);
+        }
+    }
+
+    // We iterated over specified relays and haven't found what we were
+    // looking for
+    return (OptionPtr());
+}
+
+OptionPtr
+Pkt6::getNonCopiedRelayOption(const uint16_t opt_type,
+                              const uint8_t relay_level) const {
+    if (relay_level >= relay_info_.size()) {
+        isc_throw(OutOfRange, "This message was relayed "
+                  << relay_info_.size() << " time(s)."
+                  << " There is no info about "
+                  << relay_level + 1 << " relay.");
+    }
+
+    OptionCollection::const_iterator x = relay_info_[relay_level].options_.find(opt_type);
+    if (x != relay_info_[relay_level].options_.end()) {
+        return (x->second);
+    }
+
+    return (OptionPtr());
+}
+
+OptionPtr
+Pkt6::getRelayOption(const uint16_t opt_type, const uint8_t relay_level) {
+    if (relay_level >= relay_info_.size()) {
+        isc_throw(OutOfRange, "This message was relayed "
+                  << relay_info_.size() << " time(s)."
+                  << " There is no info about "
+                  << relay_level + 1 << " relay.");
+    }
+
+    OptionCollection::iterator x = relay_info_[relay_level].options_.find(opt_type);
+    if (x != relay_info_[relay_level].options_.end()) {
+        if (copy_retrieved_options_) {
+            OptionPtr relay_option_copy = x->second->clone();
+            x->second = relay_option_copy;
+        }
+        return (x->second);
+    }
+
+    return (OptionPtr());
+}
+
+const isc::asiolink::IOAddress&
+Pkt6::getRelay6LinkAddress(uint8_t relay_level) const {
     if (relay_level >= relay_info_.size()) {
         isc_throw(OutOfRange, "This message was relayed " << relay_info_.size() << " time(s)."
                   << " There is no info about " << relay_level + 1 << " relay.");
     }
 
-    for (OptionCollection::iterator it = relay_info_[relay_level].options_.begin();
-         it != relay_info_[relay_level].options_.end(); ++it) {
-        if ((*it).second->getType() == opt_type) {
-            return (it->second);
-        }
+    return (relay_info_[relay_level].linkaddr_);
+}
+
+const isc::asiolink::IOAddress&
+Pkt6::getRelay6PeerAddress(uint8_t relay_level) const {
+    if (relay_level >= relay_info_.size()) {
+        isc_throw(OutOfRange, "This message was relayed " << relay_info_.size() << " time(s)."
+                  << " There is no info about " << relay_level + 1 << " relay.");
     }
 
-    return (OptionPtr());
+    return (relay_info_[relay_level].peeraddr_);
 }
 
 uint16_t Pkt6::getRelayOverhead(const RelayInfo& relay) const {
@@ -188,7 +281,7 @@ Pkt6::pack() {
 void
 Pkt6::packUDP() {
     try {
-        // Make sure that the buffer is empty before we start writting to it.
+        // Make sure that the buffer is empty before we start writing to it.
         buffer_out_.clear();
 
         // is this a relayed packet?
@@ -205,7 +298,7 @@ Pkt6::packUDP() {
             for (vector<RelayInfo>::iterator relay = relay_info_.begin();
                  relay != relay_info_.end(); ++relay) {
 
-                // build relay-forw/relay-repl header (see RFC3315, section 7)
+                // build relay-forw/relay-repl header (see RFC 8415, section 9)
                 buffer_out_.writeUint8(relay->msg_type_);
                 buffer_out_.writeUint8(relay->hop_count_);
                 buffer_out_.writeData(&(relay->linkaddr_.toBytes()[0]),
@@ -234,7 +327,7 @@ Pkt6::packUDP() {
 
         }
 
-        // DHCPv6 header: message-type (1 octect) + transaction id (3 octets)
+        // DHCPv6 header: message-type (1 octet) + transaction id (3 octets)
         buffer_out_.writeUint8(msg_type_);
         // store 3-octet transaction-id
         buffer_out_.writeUint8( (transid_ >> 16) & 0xff );
@@ -242,7 +335,7 @@ Pkt6::packUDP() {
         buffer_out_.writeUint8( (transid_) & 0xff );
 
         // the rest are options
-        LibDHCP::packOptions(buffer_out_, options_);
+        LibDHCP::packOptions6(buffer_out_, options_);
     }
     catch (const Exception& e) {
        // An exception is thrown and message will be written to Logger
@@ -254,7 +347,7 @@ void
 Pkt6::packTCP() {
     /// TODO Implement this function.
     isc_throw(NotImplemented, "DHCPv6 over TCP (bulk leasequery and failover)"
-              "not implemented yet.");
+              " not implemented yet.");
 }
 
 void
@@ -287,7 +380,9 @@ Pkt6::unpackUDP() {
     case DHCPV6_DECLINE:
     case DHCPV6_RECONFIGURE:
     case DHCPV6_INFORMATION_REQUEST:
-    default: // assume that uknown messages are not using relay format
+    case DHCPV6_DHCPV4_QUERY:
+    case DHCPV6_DHCPV4_RESPONSE:
+    default: // assume that unknown messages are not using relay format
         {
             return (unpackMsg(data_.begin(), data_.end()));
         }
@@ -322,15 +417,7 @@ Pkt6::unpackMsg(OptionBuffer::const_iterator begin,
 
     // If custom option parsing function has been set, use this function
     // to parse options. Otherwise, use standard function from libdhcp.
-    size_t offset;
-    if (callback_.empty()) {
-        offset = LibDHCP::unpackOptions6(opt_buffer, "dhcp6", options_);
-    } else {
-        // The last two arguments hold the DHCPv6 Relay message offset and
-        // length. Setting them to NULL because we are dealing with the
-        // not-relayed message.
-        offset = callback_(opt_buffer, "dhcp6", options_, NULL, NULL);
-    }
+    size_t offset = LibDHCP::unpackOptions6(opt_buffer, DHCP6_OPTION_SPACE, options_);
 
     // If offset is not equal to the size, then something is wrong here. We
     // either parsed past input buffer (bug in our code) or we haven't parsed
@@ -355,7 +442,7 @@ Pkt6::unpackRelayMsg() {
     // we use offset + bufsize, because we want to avoid creating unnecessary
     // copies. There may be up to 32 relays. While using InputBuffer would
     // be probably a bit cleaner, copying data up to 32 times is unacceptable
-    // price here. Hence a single buffer with offets and lengths.
+    // price here. Hence a single buffer with offsets and lengths.
     size_t bufsize = data_.size();
     size_t offset = 0;
 
@@ -376,17 +463,12 @@ Pkt6::unpackRelayMsg() {
         bufsize -= DHCPV6_RELAY_HDR_LEN; // 34 bytes (1+1+16+16)
 
         // parse the rest as options
-        OptionBuffer opt_buffer(&data_[offset], &data_[offset+bufsize]);
+        OptionBuffer opt_buffer(&data_[offset], &data_[offset] + bufsize);
 
         // If custom option parsing function has been set, use this function
         // to parse options. Otherwise, use standard function from libdhcp.
-        if (callback_.empty()) {
-            LibDHCP::unpackOptions6(opt_buffer, "dhcp6", relay.options_,
-                                    &relay_msg_offset, &relay_msg_len);
-        } else {
-            callback_(opt_buffer, "dhcp6", relay.options_,
-                      &relay_msg_offset, &relay_msg_len);
-        }
+        LibDHCP::unpackOptions6(opt_buffer, DHCP6_OPTION_SPACE, relay.options_,
+                                &relay_msg_offset, &relay_msg_len);
 
         /// @todo: check that each option appears at most once
         //relay.interface_id_ = options->getOption(D6O_INTERFACE_ID);
@@ -433,7 +515,7 @@ Pkt6::unpackRelayMsg() {
 
 void
 Pkt6::addRelayInfo(const RelayInfo& relay) {
-    if (relay_info_.size() > 32) {
+    if (relay_info_.size() > HOP_COUNT_LIMIT) {
         isc_throw(BadValue, "Massage cannot be encapsulated more than 32 times");
     }
 
@@ -449,12 +531,16 @@ Pkt6::unpackTCP() {
 
 HWAddrPtr
 Pkt6::getMACFromDUID() {
-    OptionPtr opt_duid = getOption(D6O_CLIENTID);
+    HWAddrPtr mac;
+    OptionPtr opt_duid = getNonCopiedOption(D6O_CLIENTID);
     if (!opt_duid) {
-        return (HWAddrPtr());
+        return (mac);
     }
 
     uint8_t hlen = opt_duid->getData().size();
+    if (!hlen) {
+        return (mac);
+    }
     vector<uint8_t> hw_addr(hlen, 0);
     std::vector<unsigned char> duid_data = opt_duid->getData();
 
@@ -466,75 +552,174 @@ Pkt6::getMACFromDUID() {
     {
         // 2 bytes of duid type, 2 bytes of hardware type and at least
         // 1 byte of actual identification
-        if (duid_data.size() < 5) {
-            // This duid is truncated. We can't extract anything from it.
-            return (HWAddrPtr());
+        if (duid_data.size() >= 5) {
+            uint16_t hwtype = util::readUint16(&duid_data[2],
+                                               duid_data.size() - 2);
+            mac.reset(new HWAddr(&duid_data[4], duid_data.size() - 4, hwtype));
         }
-
-        uint16_t hwtype = util::readUint16(&duid_data[2], duid_data.size() - 2);
-        return (HWAddrPtr(new HWAddr(&duid_data[4], duid_data.size() - 4,
-                                     hwtype)));
+        break;
     }
     case DUID::DUID_LLT:
     {
         // 2 bytes of duid type, 2 bytes of hardware, 4 bytes for timestamp,
         // and at least 1 byte of actual identification
-        if (duid_data.size() < 9) {
-            // This duid is truncated. We can't extract anything from it.
-            return (HWAddrPtr());
+        if (duid_data.size() >= 9) {
+            uint16_t hwtype = util::readUint16(&duid_data[2],
+                                               duid_data.size() - 2);
+            mac.reset(new HWAddr(&duid_data[8], duid_data.size() - 8, hwtype));
         }
-
-        uint16_t hwtype = util::readUint16(&duid_data[2], duid_data.size() - 2);
-        return (HWAddrPtr(new HWAddr(&duid_data[8], duid_data.size() - 8,
-                                     hwtype)));
+        break;
     }
     default:
-        return (HWAddrPtr());
+        break;
     }
+
+    if (mac) {
+        mac->source_ = HWAddr::HWADDR_SOURCE_DUID;
+    }
+
+    return (mac);
 }
 
 std::string
-Pkt6::toText() {
+Pkt6::makeLabel(const DuidPtr duid, const uint32_t transid,
+                const HWAddrPtr& hwaddr) {
+    // Create label with DUID and HW address.
+    std::stringstream label;
+    label << makeLabel(duid, hwaddr);
+
+    // Append transaction id.
+    label << ", tid=0x" << std::hex << transid << std::dec;
+
+    return (label.str());
+}
+
+std::string
+Pkt6::makeLabel(const DuidPtr duid, const HWAddrPtr& hwaddr) {
+    std::stringstream label;
+    // DUID should be present at all times, so explicitly inform when
+    // it is no present (no info).
+    label << "duid=[" << (duid ? duid->toText() : "no info")
+          << "]";
+
+    // HW address is typically not carried in the DHCPv6 messages
+    // and can be extracted using various, but not fully reliable,
+    // techniques. If it is not present, don't print anything.
+    if (hwaddr) {
+        label << ", [" << hwaddr->toText() << "]";
+    }
+
+    return (label.str());
+}
+
+std::string
+Pkt6::getLabel() const {
+    /// @todo Do not print HW address as it is unclear how it should
+    /// be retrieved if there is no access to user configuration which
+    /// specifies the order of various techniques to be used to retrieve
+    /// it.
+    return (makeLabel(getClientId(), getTransid(), HWAddrPtr()));}
+
+std::string
+Pkt6::toText() const {
     stringstream tmp;
+
+    // First print the basics
     tmp << "localAddr=[" << local_addr_ << "]:" << local_port_
-        << " remoteAddr=[" << remote_addr_
-        << "]:" << remote_port_ << endl;
-    tmp << "msgtype=" << static_cast<int>(msg_type_) << ", transid=0x" <<
+        << " remoteAddr=[" << remote_addr_ << "]:" << remote_port_ << endl;
+    tmp << "msgtype=" << static_cast<int>(msg_type_) << "(" << getName(msg_type_)
+        << "), transid=0x" <<
         hex << transid_ << dec << endl;
-    for (isc::dhcp::OptionCollection::iterator opt=options_.begin();
+
+    // Then print the options
+    for (isc::dhcp::OptionCollection::const_iterator opt=options_.begin();
          opt != options_.end();
          ++opt) {
         tmp << opt->second->toText() << std::endl;
     }
+
+    // Finally, print the relay information (if present)
+    if (!relay_info_.empty()) {
+        tmp << relay_info_.size() << " relay(s):" << endl;
+        int cnt = 0;
+        for (auto relay = relay_info_.cbegin(); relay != relay_info_.cend(); ++relay) {
+            tmp << "relay[" << cnt++ << "]: " << relay->toText();
+        }
+    } else {
+        tmp << "No relays traversed." << endl;
+    }
     return tmp.str();
 }
 
-isc::dhcp::OptionCollection
-Pkt6::getOptions(uint16_t opt_type) {
-    isc::dhcp::OptionCollection found;
+DuidPtr
+Pkt6::getClientId() const {
+    OptionPtr opt_duid = getNonCopiedOption(D6O_CLIENTID);
+    try {
+        // This will throw if the DUID length is larger than 128 bytes
+        // or is too short.
+        return (opt_duid ? DuidPtr(new DUID(opt_duid->getData())) : DuidPtr());
+    } catch (...) {
+        // Do nothing. This method is used only by getLabel(), which is
+        // used for logging purposes. We should not throw, but rather
+        // report no DUID. We should not log anything, as we're in the
+        // process of logging something for this packet. So the only
+        // choice left is to return an empty pointer.
+    }
+    return (DuidPtr());
+}
 
-    for (OptionCollection::const_iterator x = options_.begin();
-         x != options_.end(); ++x) {
-        if (x->first == opt_type) {
-            found.insert(make_pair(opt_type, x->second));
+isc::dhcp::OptionCollection
+Pkt6::getNonCopiedOptions(const uint16_t opt_type) const {
+    std::pair<OptionCollection::const_iterator,
+              OptionCollection::const_iterator> range = options_.equal_range(opt_type);
+    return (OptionCollection(range.first, range.second));
+}
+
+isc::dhcp::OptionCollection
+Pkt6::getOptions(const uint16_t opt_type) {
+    OptionCollection options_copy;
+
+    std::pair<OptionCollection::iterator,
+              OptionCollection::iterator> range = options_.equal_range(opt_type);
+    // If options should be copied on retrieval, we should now iterate over
+    // matching options, copy them and replace the original ones with new
+    // instances.
+    if (copy_retrieved_options_) {
+        for (OptionCollection::iterator opt_it = range.first;
+             opt_it != range.second; ++opt_it) {
+            OptionPtr option_copy = opt_it->second->clone();
+            opt_it->second = option_copy;
         }
     }
-    return (found);
+    // Finally, return updated options. This can also be empty in some cases.
+    return (OptionCollection(range.first, range.second));
 }
 
 const char*
-Pkt6::getName(uint8_t type) {
+Pkt6::getName(const uint8_t type) {
+    static const char* ADVERTISE = "ADVERTISE";
     static const char* CONFIRM = "CONFIRM";
     static const char* DECLINE = "DECLINE";
     static const char* INFORMATION_REQUEST = "INFORMATION_REQUEST";
+    static const char* LEASEQUERY = "LEASEQUERY";
+    static const char* LEASEQUERY_REPLY = "LEASEQUERY_REPLY";
     static const char* REBIND = "REBIND";
+    static const char* RECONFIGURE = "RECONFIGURE";
+    static const char* RELAY_FORW = "RELAY_FORWARD";
+    static const char* RELAY_REPL = "RELAY_REPLY";
     static const char* RELEASE = "RELEASE";
     static const char* RENEW = "RENEW";
+    static const char* REPLY = "REPLY";
     static const char* REQUEST = "REQUEST";
     static const char* SOLICIT = "SOLICIT";
+    static const char* DHCPV4_QUERY = "DHCPV4_QUERY";
+    static const char* DHCPV4_RESPONSE = "DHCPV4_RESPONSE";
     static const char* UNKNOWN = "UNKNOWN";
 
     switch (type) {
+    case DHCPV6_ADVERTISE:
+        return (ADVERTISE);
+
     case DHCPV6_CONFIRM:
         return (CONFIRM);
 
@@ -544,21 +729,45 @@ Pkt6::getName(uint8_t type) {
     case DHCPV6_INFORMATION_REQUEST:
         return (INFORMATION_REQUEST);
 
+    case DHCPV6_LEASEQUERY:
+        return (LEASEQUERY);
+
+    case DHCPV6_LEASEQUERY_REPLY:
+        return (LEASEQUERY_REPLY);
+
     case DHCPV6_REBIND:
         return (REBIND);
 
+    case DHCPV6_RECONFIGURE:
+        return (RECONFIGURE);
+
+    case DHCPV6_RELAY_FORW:
+        return (RELAY_FORW);
+
+    case DHCPV6_RELAY_REPL:
+        return (RELAY_REPL);
+
     case DHCPV6_RELEASE:
         return (RELEASE);
 
     case DHCPV6_RENEW:
         return (RENEW);
 
+    case DHCPV6_REPLY:
+        return (REPLY);
+
     case DHCPV6_REQUEST:
         return (REQUEST);
 
     case DHCPV6_SOLICIT:
         return (SOLICIT);
 
+    case DHCPV6_DHCPV4_QUERY:
+        return (DHCPV4_QUERY);
+
+    case DHCPV6_DHCPV4_RESPONSE:
+        return (DHCPV4_RESPONSE);
+
     default:
         ;
     }
@@ -572,8 +781,8 @@ const char* Pkt6::getName() const {
 void Pkt6::copyRelayInfo(const Pkt6Ptr& question) {
 
     // We use index rather than iterator, because we need that as a parameter
-    // passed to getRelayOption()
-    for (int i = 0; i < question->relay_info_.size(); ++i) {
+    // passed to getNonCopiedRelayOption()
+    for (size_t i = 0; i < question->relay_info_.size(); ++i) {
         RelayInfo info;
         info.msg_type_ = DHCPV6_RELAY_REPL;
         info.hop_count_ = question->relay_info_[i].hop_count_;
@@ -582,12 +791,18 @@ void Pkt6::copyRelayInfo(const Pkt6Ptr& question) {
 
         // Is there an interface-id option in this nesting level?
         // If there is, we need to echo it back
-        OptionPtr opt = question->getRelayOption(D6O_INTERFACE_ID, i);
+        OptionPtr opt = question->getNonCopiedRelayOption(D6O_INTERFACE_ID, i);
         // taken from question->RelayInfo_[i].options_
         if (opt) {
             info.options_.insert(make_pair(opt->getType(), opt));
         }
 
+        // Same for relay-source-port option
+        opt = question->getNonCopiedRelayOption(D6O_RELAY_SOURCE_PORT, i);
+        if (opt) {
+            info.options_.insert(make_pair(opt->getType(), opt));
+        }
+
         /// @todo: Implement support for ERO (Echo Request Option, RFC4994)
 
         // Add this relay-forw info (client's message) to our relay-repl
@@ -609,116 +824,119 @@ Pkt6::getMACFromSrcLinkLocalAddr() {
 
 HWAddrPtr
 Pkt6::getMACFromIPv6RelayOpt() {
-    if (relay_info_.empty()) {
-        // This is a direct message
-        return (HWAddrPtr());
-    }
-    // RFC6969 Section 6: Look for the client_linklayer_addr option on the
-    // relay agent closest to the client
-    OptionPtr opt = getAnyRelayOption(D6O_CLIENT_LINKLAYER_ADDR, RELAY_GET_FIRST);
-    if (opt) {
-        const OptionBuffer data = opt->getData();
-        if (data.size() < 3) {
-            // This client link address option is truncated. It's supposed to be
-            // 2 bytes of link-layer type followed by link-layer address.
-            return (HWAddrPtr());
-        }
+    HWAddrPtr mac;
 
-        // +2, -2 means to skip the initial 2 bytes which are hwaddress type
-        return (HWAddrPtr(new HWAddr(&data[0] + 2, data.size() - 2,
-                                     opt->getUint16())));
-    } else {
-        return (HWAddrPtr());
+    // This is not a direct message
+    if (!relay_info_.empty()) {
+        // RFC6969 Section 6: Look for the client_linklayer_addr option on the
+        // relay agent closest to the client
+        OptionPtr opt = getAnyRelayOption(D6O_CLIENT_LINKLAYER_ADDR,
+                                          RELAY_GET_FIRST);
+        if (opt) {
+            const OptionBuffer data = opt->getData();
+            // This client link address option is supposed to be
+            // 2 bytes of link-layer type followed by link-layer address.
+            if (data.size() >= 3) {
+                // +2, -2 means to skip the initial 2 bytes which are
+                // hwaddress type
+                mac.reset(new HWAddr(&data[0] + 2, data.size() - 2,
+                          opt->getUint16()));
+
+                mac->source_ = HWAddr::HWADDR_SOURCE_CLIENT_ADDR_RELAY_OPTION;
+            }
+        }
     }
+
+    return mac;
 }
 
 HWAddrPtr
 Pkt6::getMACFromDocsisModem() {
+    HWAddrPtr mac;
     OptionVendorPtr vendor = boost::dynamic_pointer_cast<
-        OptionVendor>(getOption(D6O_VENDOR_OPTS));
+        OptionVendor>(getNonCopiedOption(D6O_VENDOR_OPTS));
 
     // Check if this is indeed DOCSIS3 environment
-    if (!vendor || vendor->getVendorId() != VENDOR_ID_CABLE_LABS) {
-        return (HWAddrPtr());
+    if (vendor && vendor->getVendorId() == VENDOR_ID_CABLE_LABS) {
+        // If it is, try to get device-id option
+        OptionPtr device_id = vendor->getOption(DOCSIS3_V6_DEVICE_ID);
+        if (device_id) {
+            // If the option contains any data, use it as MAC address
+            if (!device_id->getData().empty()) {
+                mac.reset(new HWAddr(device_id->getData(), HTYPE_DOCSIS));
+                mac->source_ = HWAddr::HWADDR_SOURCE_DOCSIS_MODEM;
+            }
+        }
     }
 
-    // If it is, try to get device-id option
-    OptionPtr device_id = vendor->getOption(DOCSIS3_V6_DEVICE_ID);
-    if (!device_id) {
-        return (HWAddrPtr());
-    }
-
-    // If the option contains any data, use it as MAC address
-    if (!device_id->getData().empty()) {
-        return (HWAddrPtr(new HWAddr(device_id->getData(), HTYPE_DOCSIS)));
-    } else {
-        return (HWAddrPtr());
-    }
+    return mac;
 }
 
 HWAddrPtr
 Pkt6::getMACFromDocsisCMTS() {
-    if (relay_info_.empty()) {
-        // This message didn't pass through a CMTS, so there won't be any
-        // CMTS-specific options in it.
-        return (HWAddrPtr());
+    HWAddrPtr mac;
+
+    // If the message passed through a CMTS, there'll
+    // CMTS-specific options in it.
+    if (!relay_info_.empty()) {
+        OptionVendorPtr vendor = boost::dynamic_pointer_cast<
+            OptionVendor>(getAnyRelayOption(D6O_VENDOR_OPTS,
+                                            RELAY_SEARCH_FROM_CLIENT));
+
+        // Check if this is indeed DOCSIS3 environment
+        if (vendor && vendor->getVendorId() == VENDOR_ID_CABLE_LABS) {
+            // Try to get cable modem mac
+            OptionPtr cm_mac = vendor->getOption(DOCSIS3_V6_CMTS_CM_MAC);
+
+            // If the option contains any data, use it as MAC address
+            if (cm_mac && !cm_mac->getData().empty()) {
+                mac.reset(new HWAddr(cm_mac->getData(), HTYPE_DOCSIS));
+                mac->source_ = HWAddr::HWADDR_SOURCE_DOCSIS_CMTS;
+            }
+        }
     }
 
-    OptionVendorPtr vendor = boost::dynamic_pointer_cast<
-        OptionVendor>(getAnyRelayOption(D6O_VENDOR_OPTS,
-                                        RELAY_SEARCH_FROM_CLIENT));
-
-    // Check if this is indeed DOCSIS3 environment
-    if (!vendor || vendor->getVendorId() != VENDOR_ID_CABLE_LABS) {
-        return (HWAddrPtr());
-    }
-
-    // If it is, try to get cable modem mac
-    OptionPtr cm_mac = vendor->getOption(DOCSIS3_V6_CMTS_CM_MAC);
-    if (!cm_mac) {
-        return (HWAddrPtr());
-    }
-
-    // If the option contains any data, use it as MAC address
-    if (!cm_mac->getData().empty()) {
-        return (HWAddrPtr(new HWAddr(cm_mac->getData(), HTYPE_DOCSIS)));
-    } else {
-        return (HWAddrPtr());
-    }
+    return (mac);
 }
 
 HWAddrPtr
 Pkt6::getMACFromRemoteIdRelayOption() {
-    if (relay_info_.empty()) {
-        // This is a direct message
-        return (HWAddrPtr());
+    HWAddrPtr mac;
+
+    // If this is relayed message
+    if (!relay_info_.empty()) {
+        // Get remote-id option from a relay agent closest to the client
+        OptionPtr opt = getAnyRelayOption(D6O_REMOTE_ID, RELAY_GET_FIRST);
+        if (opt) {
+            const OptionBuffer data = opt->getData();
+            // This remote-id option is supposed to be 4 bytes of
+            // of enterprise-number followed by remote-id.
+            if (data.size() >= 5) {
+                // Let's get the interface this packet was received on.
+                // We need it to get the hardware type.
+                IfacePtr iface = IfaceMgr::instance().getIface(iface_);
+                uint16_t hwtype = 0; // not specified
+
+                // If we get the interface HW type, great! If not,
+                // let's not panic.
+                if (iface) {
+                    hwtype = iface->getHWType();
+                }
+
+                size_t len = data.size() - 4;
+
+                if (len > HWAddr::MAX_HWADDR_LEN) {
+                    len = HWAddr::MAX_HWADDR_LEN;
+                }
+
+                // Skip the initial 4 bytes which are enterprise-number.
+                mac.reset(new HWAddr(&data[0] + 4, len, hwtype));
+                mac->source_ = HWAddr::HWADDR_SOURCE_REMOTE_ID;
+            }
+        }
     }
 
-    // Get remote-id option from a relay agent closest to the client
-    OptionPtr opt = getAnyRelayOption(D6O_REMOTE_ID, RELAY_GET_FIRST);
-    if (opt) {
-        const OptionBuffer data = opt->getData();
-        if (data.size() < 5) {
-            // This remote-id option is truncated. It's supposed to be
-            // 4 bytes of enterprise-number followed by remote-id.
-            return (HWAddrPtr());
-        }
-
-        // Let's get the interface this packet was received on. We need it to get
-        // the hardware type.
-        IfacePtr iface = IfaceMgr::instance().getIface(iface_);
-        uint16_t hwtype = 0; // not specified
-
-        // If we get the interface HW type, great! If not, let's not panic.
-        if (iface) {
-            hwtype = iface->getHWType();
-        }
-
-        // Skip the initial 4 bytes which are enterprise-number.
-        return (HWAddrPtr(new HWAddr(&data[0] + 4, data.size() - 4, hwtype)));
-    } else {
-        return (HWAddrPtr());
-    }
+    return (mac);
 }
 
 } // end of isc::dhcp namespace
