@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2019-2022 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -205,6 +205,10 @@ CBControlDHCPv6::databaseConfigApply(const db::BackendSelector& backend_selector
         // Match expressions are not initialized for classes returned from the config backend.
         // We have to ensure to initialize them before they can be used by the server.
         client_classes.initMatchExpr(AF_INET6);
+
+        // Class options also need to be created when returned from the config backend.
+        client_classes.createOptions(external_cfg->getCfgOptionDef());
+
         external_cfg->setClientClassDictionary(boost::make_shared<ClientClassDictionary>(client_classes));
     }
 
@@ -223,7 +227,7 @@ CBControlDHCPv6::databaseConfigApply(const db::BackendSelector& backend_selector
             // In order to take advantage of the dynamic inheritance of global
             // parameters to a shared network we need to set a callback function
             // for each network to allow for fetching global parameters.
-            (*network)->setFetchGlobalsFn([] () -> ConstElementPtr {
+            (*network)->setFetchGlobalsFn([] () -> ConstCfgGlobalsPtr {
                 return (CfgMgr::instance().getCurrentCfg()->getConfiguredGlobals());
             });
             external_cfg->getCfgSharedNetworks6()->add((*network));
@@ -245,7 +249,7 @@ CBControlDHCPv6::databaseConfigApply(const db::BackendSelector& backend_selector
             // In order to take advantage of the dynamic inheritance of global
             // parameters to a subnet we need to set a callback function for each
             // subnet to allow for fetching global parameters.
-            (*subnet)->setFetchGlobalsFn([] () -> ConstElementPtr {
+            (*subnet)->setFetchGlobalsFn([] () -> ConstCfgGlobalsPtr {
                 return (CfgMgr::instance().getCurrentCfg()->getConfiguredGlobals());
             });
             external_cfg->getCfgSubnets6()->add((*subnet));
